==> ejc-ztpccom-impl-3.0.0-20230717.143318-54-sources.jar: com/ejianc/business/pub/controller/DataDictionaryController.java <==
package com.ejianc.business.pub.controller;

import java.io.Serializable;

import com.ejianc.business.pub.util.Constants;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.api.IProjectSetApi;
import com.ejianc.foundation.share.vo.ProjectPoolSetVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.pub.bean.DataDictionaryEntity;
import com.ejianc.business.pub.service.IDataDictionaryService;
import com.ejianc.business.pub.vo.DataDictionaryVO;

/**
 * 数据字典
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("dataDictionary")
public class DataDictionaryController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "DICTIONARY";//此处需要根据实际修改

    @Autowired
    private IDataDictionaryService service;

    @Autowired
    private IProjectSetApi projectSetApi;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DataDictionaryVO> saveOrUpdate(@RequestBody DataDictionaryVO saveOrUpdateVO) {
        CommonResponse<DataDictionaryVO> response = service.saveOrUpdate(saveOrUpdateVO);
        return response;
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DataDictionaryVO> queryDetail(Long id) {
    	DataDictionaryEntity entity = service.selectById(id);
    	DataDictionaryVO vo = BeanMapper.map(entity, DataDictionaryVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DataDictionaryVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (DataDictionaryVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DataDictionaryVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DataDictionaryVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
//        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //项目部 id
        List<String> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            departmentIds.add(org.getId()+"");
        });

        if(CollectionUtils.isNotEmpty(departmentIds)) {
            departmentIds.add(Constants.LEVEL_GROUP);
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgCode", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        LinkedHashMap<String, String> orderMap = new LinkedHashMap<>();
        orderMap.put("category_id", QueryParam.DESC);
        orderMap.put("level", QueryParam.ASC);
        orderMap.put("line", QueryParam.ASC);

        param.setOrderMap(orderMap);

        IPage<DataDictionaryEntity> page = service.queryPage(param,false);
        IPage<DataDictionaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), DataDictionaryVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<DataDictionaryEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("DataDictionary-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refDataDictionaryData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DataDictionaryVO>> refDataDictionaryData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);

        QueryParam param = new QueryParam();
        if(null == conditionMap.get("projectId")) {
            return CommonResponse.error("查询失败，参数condition中缺少项projectId！");
        }else if(null == conditionMap.get("categoryCode")){
            return CommonResponse.error("查询失败，参数condition中缺少项categoryCode！");
        }

        Long projectId = Long.valueOf(conditionMap.get("projectId").toString());

        CommonResponse<ProjectPoolSetVO> responseVO = projectSetApi.getProjectId(projectId);
        if(responseVO.getCode() == 0 && responseVO.getData() != null){
            ProjectPoolSetVO projectPoolSetVO = responseVO.getData();

            List<String> orgCodes = new ArrayList<>();
            orgCodes.add(projectPoolSetVO.getProjectDepartmentId().toString());
            orgCodes.add(Constants.LEVEL_GROUP);

            param.getParams().put("orgCode",new Parameter(QueryParam.IN,orgCodes));

            String categoryCode = conditionMap.get("categoryCode").toString();
            param.getParams().put("categoryCode", new Parameter(QueryParam.EQ, categoryCode));

            param.setPageSize(pageSize);
            param.setPageIndex(pageNumber);
            param.setSearchText(searchText);
            param.setSearchObject(searchObject);
            /** 租户隔离 */
//        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

            IPage<DataDictionaryEntity> page = service.queryPage(param,false);
            IPage<DataDictionaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(BeanMapper.mapList(page.getRecords(), DataDictionaryVO.class));
            return CommonResponse.success("查询参照数据成功！",pageData);
        }else{
            return CommonResponse.success("查询参照数据成功！",null);
        }

     }
}

==> ejc-ztpccom-impl-3.0.0-20240325.072041-93-sources.jar: com/ejianc/business/pub/controller/DataDictionaryController.java <==
package com.ejianc.business.pub.controller;

import java.io.Serializable;

import com.ejianc.business.pub.util.Constants;
import com.ejianc.business.pub.vo.DataDictionaryVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.share.api.IProjectSetApi;
import com.ejianc.foundation.share.vo.ProjectPoolSetVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.pub.bean.DataDictionaryEntity;
import com.ejianc.business.pub.service.IDataDictionaryService;

/**
 * 数据字典
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("dataDictionary")
public class DataDictionaryController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "DICTIONARY";//此处需要根据实际修改

    @Autowired
    private IDataDictionaryService service;

    @Autowired
    private IProjectSetApi projectSetApi;

    @Autowired
    private SessionManager sessionManager;


    @RequestMapping(value = "/queryUnitBumber", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<List<DataDictionaryVO>> queryUnitBumber(@RequestBody Map<String, String> conditionMap) {
        return CommonResponse.success(service.queryUnitBumber(conditionMap));
    }

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<DataDictionaryVO> saveOrUpdate(@RequestBody DataDictionaryVO saveOrUpdateVO) {
        CommonResponse<DataDictionaryVO> response = service.saveOrUpdate(saveOrUpdateVO);
        return response;
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<DataDictionaryVO> queryDetail(Long id) {
    	DataDictionaryEntity entity = service.selectById(id);
    	DataDictionaryVO vo = BeanMapper.map(entity, DataDictionaryVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<DataDictionaryVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (DataDictionaryVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(DataDictionaryVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<DataDictionaryVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
//        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //项目部 id
        List<String> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            departmentIds.add(org.getId()+"");
        });

        if(CollectionUtils.isNotEmpty(departmentIds)) {
            departmentIds.add(Constants.LEVEL_GROUP);
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgCode", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        LinkedHashMap<String, String> orderMap = new LinkedHashMap<>();
        orderMap.put("category_id", QueryParam.DESC);
        orderMap.put("level", QueryParam.ASC);
        orderMap.put("line", QueryParam.ASC);

        param.setOrderMap(orderMap);

        IPage<DataDictionaryEntity> page = service.queryPage(param,false);
        IPage<DataDictionaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), DataDictionaryVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<DataDictionaryEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("DataDictionary-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refDataDictionaryData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<DataDictionaryVO>> refDataDictionaryData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        Map<String, Object> conditionMap = JSONObject.parseObject(condition, Map.class);

        QueryParam param = new QueryParam();
        if(null == conditionMap.get("projectId")) {
            return CommonResponse.error("查询失败，参数condition中缺少项projectId！");
        }else if(null == conditionMap.get("categoryCode")){
            return CommonResponse.error("查询失败，参数condition中缺少项categoryCode！");
        }

        Long projectId = Long.valueOf(conditionMap.get("projectId").toString());

        CommonResponse<ProjectPoolSetVO> responseVO = projectSetApi.getProjectId(projectId);
        if(responseVO.getCode() == 0 && responseVO.getData() != null){
            ProjectPoolSetVO projectPoolSetVO = responseVO.getData();

            List<String> orgCodes = new ArrayList<>();
            orgCodes.add(projectPoolSetVO.getProjectDepartmentId().toString());
            orgCodes.add(Constants.LEVEL_GROUP);

            param.getParams().put("orgCode",new Parameter(QueryParam.IN,orgCodes));

            String categoryCode = conditionMap.get("categoryCode").toString();
            param.getParams().put("categoryCode", new Parameter(QueryParam.EQ, categoryCode));

            param.setPageSize(pageSize);
            param.setPageIndex(pageNumber);
            param.setSearchText(searchText);
            param.setSearchObject(searchObject);
            /** 租户隔离 */
//        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

            IPage<DataDictionaryEntity> page = service.queryPage(param,false);
            IPage<DataDictionaryVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
            pageData.setRecords(BeanMapper.mapList(page.getRecords(), DataDictionaryVO.class));
            return CommonResponse.success("查询参照数据成功！",pageData);
        }else{
            return CommonResponse.success("查询参照数据成功！",null);
        }

     }


}
